<!DOCTYPE html>
<html lang="en">
	<head>
		<meta charset='utf-8'>
		<meta http-equiv="X-UA-Compatible" content="chrome=1">
		<meta name="twitter:card" content="summary"/>
		<meta name="twitter:title" content="zotan's blog"/>
		<meta name="twitter:description" content="ADHD & Notetaking: an autistic perspective"/>
		<link rel="stylesheet" href="/style.css">
		<title>zotan's blog</title>
	</head>
	<body>
		<header>
			<div class="container">
				<h1><a href="/blog">zotan's blog</a></h1>
				<?php if($_SERVER['HTTP_HOST'] === "zotan.pw" || $_SERVER['HTTP_HOST'] === "zotan.pw.dev"): ?>
					<h2 style="margin-bottom: 0px;">Welcome internet user.</h2>
				<?php else: ?>
					<h2 style="margin-bottom: 0px;">Welcome <?php echo($_SERVER['SERVER_PROTOCOL'])?> internet user.</h2>
				<?php endif; ?>
			<small><a href="/blog">Back to blog overview</a></small>
			</div>
		</header>
		<div class="container">
			<section id="main_content">
			<b>2021-08-07</b> - an 8 minute read (150 wpm)
			<h1 id="post">ADHD & Notetaking: an autistic perspective</h1>
			<div align="justify">
				<p>
					If you are living with ADHD, diagnosed or not, the following things might sound familiar: <i>"I forgot to write that down"</i>, <i>"I forgot to do that"</i>, <i>"I don't remember that"</i>.
				</p>
				<p>
					If you ask neurotypical people what they do to resolve that, they will probably give you answers ranging from "Oh I just have it all in my head" to "Just use a todo list / GTD system / bullet journal", both equally unhelpful to most neurodiverse folks I know.
				</p>
				<p>
					Reading <a href="https://xeiaso.net/blog/gtd-on-paper-2021-06-13" target="_blank">this article</a> by Xe inspired me to tackle this problem for myself. (I highly encourage you to read the linked post along with the rest of their blog)
				</p>
				<p>
					Now, back to the topic at hand. As mentioned, there are many common strategies for managing tasks and notes, many of which simply do not work for me, but let's go through the why and try to find something that works from there.
				</p>
				<p>
					 <h3>Journals, paper and other physical ways of notetaking</h3>
					 The most immediate problem with this one is something many ADHD folks will know very well - keeping track of the physical thing. Many times have I lost track of notebooks, journals, diaries or anything related, often times not finding them again to this day. For something I have to rely on (physical extension of my brain, my memories, my thoughts), that's bad. It's hard to forget your head, after all - even though a certain figure of speech might suggest otherwise.
				</p>
				<p>
					Another issue, that links more into the <i>autistic perspective</i> part of the title, is the thing that many people like about paper - its append-only nature. I have very specific ideas about how I want things structured - and those ideas and needs vary with time and with the contents of the page. You just can't (easily and realistically) re-write the entire page every time those change, which makes paper inconvenient at best and irritating at worst.
				</p>
				<p>
					But there are also some wonderful things about paper, some even come as a direct consequence of the problems I just described. You can just start writing, there are no creative restrictions on what you can and can't write, draw or otherwise do with the page, there is no fixed set of design choices, style guidelines and whatnot. The append-only nature also forces you to stop worrying about mistakes, and ideally should let you be in full control of writing out thoughts.
				</p>
				<p>
					To summarize: Paper is problematic because of the physical and append-only nature, but can also great because of the freedom and implicit restrictions it brings onto the table. What I then set out to do is translating those concepts into the digital world, as closely adhering to those concepts (and other things my brain likes that I didn't cover in this post) as possible.
				</p>
				<p>
					<h3>Markdown and the digital world</h3>
					Once you dabble with digital notetaking for more than a few minutes, there's no way not to stumble upon Markdown. And there's good reason for that, being an easy to understand, simple and human-readable (in contrast to programmer-readable) markup language.
				</p>
				<p>
					Those things also bring caveats with them, however. Simplicity inherently means limitation, and that's also true here. There isn't that much most Markdown renderers can do. Even worse, there is fragmentation in the Markdown space, with plain Markdown, GitHub-flavored Markdown (GFM) and MultiMarkdown as examples, not to speak of the variety of ways different renderers for the same specification actually interpret things.
				</p>
				<p>
					Where does that leave us, then? I think Markdown is great, just not the full story we need here. It's a great starting point, and that's why my personal solution builds upon Markdown. So what is it that I currently (and thus far successfully, i.e. there when I need it, how I need it, as I want it) use?
				</p>
				<p>
					It's a combination of <a href="https://obsidian.md" target="_blank">Obsidian</a> (a fancy Markdown editor, self-proclaimed "second brain"), some plugins, a custom theme, and most importantly, <i>not using the Markdown <b>renderer</b></i>. You might wonder how that works, isn't markdown supposed to be rendered? To which I say - yes, but we can do better. The one thing you are losing with that click of a button is control. Suddenly you have the version of what you wrote in front of you that the renderer decided on, not how you wanted it to look and feel. Which defeats the entire purpose of this project, to get something that offers creative freedom close to physical paper, without being convoluted to use.
				</p>
				<p>
					<h3>Putting it all together</h3>
					So how does my setup look like exactly? Like <a href="/blog/img/adhd-and-notes.png" target="_blank">this</a>. Let me explain what you are looking at here. On the left there is a tree view of the directory structure that is currently open in Obsidian.
				</p>
				<p>
					From top to bottom: <i>Events</i> are things like conferences and similar, <i>Journal</i> is where the daily notes go, <i>Knowledge</i> is a categorized map of information and trivia that might be useful again in the future, <i>Meta</i> is stuff relevant for debugging Obsidian itself, <i>Notes</i> are uncategorized but titled notes, <i>People</i> is for keeping track of people I know (for the non-ADHD people reading this, yes, this is necessary, I regularly forget basic things about people very close to me), <i>Places</i> is the same thing but for Places like restaurants and stuff (important to keep track of what I eat and where to get it and stuff), <i>Projects</i> is pretty self-explanatory, <i>Vault</i> is the "system folder" where all the templates and attachments go, and <i>Zettelkasten</i> is for untitled notes. I have a shortcut configured that will create one of those untitled notes so I can just type out a thought and figure out what it's about later.
				</p>
				<p>
					The file that's open is the daily journal template. This is used to automatically generate the daily journal entry when I click on a date in the calendar applet you can see on the top right. I then type out basic info about the day (where I was when I woke up, when I woke up) and move over incomplete TODOs from yesterday's daily note. You will also notice the text editor is, well, in edit mode, with a nice monospace font. This allows me to customize the spacing of individual elements in the documents however I want (just like paper), which would all get lost when rendering to HTML.
				</p>
				<p>
					<h3>Summary and conclusion</h3>
					This setup allows me to write freely, structure everything the same way my brain is structured, keep track of what I've been doing, keep track of things that still need to be done, and much more. Have I forgotten about it? Yes - two times over the past month. In comparison to previous methods, this is great! It's also fairly easy to reconstruct the past day or two, so I think I'm doing okay.

				</p>
				<p>
					I won't pretend that this system will work for everyone, but I do hope that you will find some useful information in this writeup. If you have any questions (or want me to help you with Markdown, Obsidian or any other part of this setup), feel free to contact me. (Links for that are on the <a href="/#contact">main site</a>)
				</p>
				<p>
					I hope this post was interesting for you, being the first time I've ever written one like it. If you have any comments on the blog or my writing style or just this post in general, please contact me as well. In any case, thanks for reading and have a wonderful day!
				</p>
			</div>
			<p style="color: #666666"><i>This request was served by <?php echo gethostname() ?> in <?php echo(round((microtime(true) - $_SERVER["REQUEST_TIME_FLOAT"])*1000, 2)) ?> ms<i></p>
		</div>
	</body>
</html>
